Re: [pcre-dev] Patch to fix typos

Inizio della pagina
Delete this message
Autore: Stepan Kasal
Data:  
To: pcre-dev
Oggetto: Re: [pcre-dev] Patch to fix typos
Hi,

On Tue, Nov 20, 2007 at 09:53:46AM +0000, Philip Hazel wrote:
> Thanks. They weren't typos; they show my past history as an IBM
> mainframe programmer. :-) IBM uses the word "alphameric" for
> "alphanumeric", or at least, they used to in the 1970s and 1980s.


> [Interestingly, the word has made it into the Oxford English Dictionary
> - the online version, anyway: "Contraction of ALPHA-NUMERIC" and gives a
> 1956 quotation to support it.]


wow, that's really interesting! Now I'm ashamed I spoiled the magic.

> (I just noticed I wrote "write" instead of "right" in
> a message I posted. Sigh.)


I almost did the same a day or two ago... Must be spots on sun!

And now for something completely different:
s/backslash/backspace/

:-)

Cheers,
    Stepan Kasal

Index: pcre_compile.c
===================================================================
--- pcre_compile.c    (revision 274)
+++ pcre_compile.c    (working copy)
@@ -2787,7 +2787,7 @@
         c = check_escape(&ptr, errorcodeptr, cd->bracount, options, TRUE);
         if (*errorcodeptr != 0) goto FAILED;


-        if (-c == ESC_b) c = '\b';       /* \b is backslash in a class */
+        if (-c == ESC_b) c = '\b';       /* \b is backspace in a class */
         else if (-c == ESC_X) c = 'X';   /* \X is literal X in a class */
         else if (-c == ESC_R) c = 'R';   /* \R is literal R in a class */
         else if (-c == ESC_Q)            /* Handle start of quoted string */
@@ -3076,7 +3076,7 @@
           d = check_escape(&ptr, errorcodeptr, cd->bracount, options, TRUE);
           if (*errorcodeptr != 0) goto FAILED;


           /* \b is backslash; \X is literal X; \R is literal R; any other
           special means the '-' was literal */
@@ -3076,7 +3076,7 @@


-          /* \b is backslash; \X is literal X; \R is literal R; any other
+          /* \b is backspace; \X is literal X; \R is literal R; any other
           special means the '-' was literal */



           if (d < 0)